@@ -1,6 +1,9 @@
 """Scan primitive."""
 
 from __future__ import division
+from __future__ import absolute_import
+from six.moves import range
+from six.moves import zip
 
 __copyright__ = """Copyright 2011-2012 Andreas Kloeckner"""
 
@@ -393,15 +396,21 @@ RADIX_SORT_OUTPUT_STMT_TPL = Template(r"""//CL//
 
 # {{{ driver
 
+# import hoisted here to be used as a default argument in the constructor
+from pyopencl.scan import GenericScanKernel
+
+
 class RadixSort(object):
     """Provides a general `radix sort <https://en.wikipedia.org/wiki/Radix_sort>`_
     on the compute device.
 
+    .. seealso:: :class:`pyopencl.algorithm.BitonicSort`
+
     .. versionadded:: 2013.1
     """
     def __init__(self, context, arguments, key_expr, sort_arg_names,
             bits_at_a_time=2, index_dtype=np.int32, key_dtype=np.uint32,
-            options=[]):
+            scan_kernel=GenericScanKernel, options=[]):
         """
         :arg arguments: A string of comma-separated C argument declarations.
             If *arguments* is specified, then *input_expr* must also be
@@ -469,8 +478,7 @@ class RadixSort(object):
         scan_preamble = preamble \
                 + RADIX_SORT_SCAN_PREAMBLE_TPL.render(**codegen_args)
 
-        from pyopencl.scan import GenericScanKernel
-        self.scan_kernel = GenericScanKernel(
+        self.scan_kernel = scan_kernel(
                 context, scan_dtype,
                 arguments=scan_arguments,
                 input_expr="scan_t_from_value(%s, base_bit, i)" % key_expr,
@@ -821,8 +829,8 @@ class ListOfListsBuilder:
         from pyopencl.tools import VectorArg, OtherArg
         kernel_list_args = [
                 VectorArg(index_dtype, "plb_%s_count" % name)
-                    for name, dtype in self.list_names_and_dtypes
-                    if name not in self.count_sharing]
+                for name, dtype in self.list_names_and_dtypes
+                if name not in self.count_sharing]
 
         user_list_args = []
         for name, dtype in self.list_names_and_dtypes:
